<!-- 
This README describes the package. If you publish this package to pub.dev,
this README's contents appear on the landing page for your package.

For information about how to write a good package README, see the guide for
[writing package pages](https://dart.dev/guides/libraries/writing-package-pages). 

For general information about developing packages, see the Dart guide for
[creating packages](https://dart.dev/guides/libraries/create-library-packages)
and the Flutter guide for
[developing packages and plugins](https://flutter.dev/developing-packages). 
-->

An `AuthProvider` interface with FirebaseAuth implementation

<!--
## Features

Maybe in future: List what your package can do. Maybe include images, gifs, or videos.

## Getting started

Maybe in future: List prerequisites and provide or point to information on how to
start using the package.
-->

## Usage

```dart

final AuthProvider authProvider = FirebaseAuthProvider();
authProvider.signOut();

final signInResult = authProvider.emailPasswordSignIn(
    LoginCredentials("some@email.com", "secretPassword"));

final AuthUser currentUser = authProvider.currentAuthUser;
print("Currently logged in as: ${currentUser.displayName}, ${currentUser.email}, ${currentUser.id}");

authProvider.authUserChanged.listen((authUser) {
    print("Auth user changed");
    print("Is logged in: ${authUser.isLoggedIn}");
    if (authUser.isLoggedIn) {
    print("Currently logged in as: ${currentUser.displayName}, ${currentUser.email}, ${currentUser.id}");
    }
});
```

Use the `AuthStateWrapper` to handle listening to the current auth state and display the correct
page accordingly.

```dart

final AuthStateWrapper authStateWrapper = AuthStateWrapper(
    authProvider: authProvider,
    signedIn: (context) => HomePage(),
    notSignedIn: (context) => LoginPage(),
    loading: (context) => const CircularProgressIndicator(),
    error: (context, error) => Text("Error occurred: $error"));
```

<!--
## Additional information

Maybe in future: Tell users more about the package: where to find more information, how to 
contribute to the package, how to file issues, what response they can expect 
from the package authors, and more.
-->