class AuthUser {
  final String id;
  final String displayName;
  final String email;
  final bool emailVerified;
  final Future<void> Function() sendVerificationEmail;
  final Future<void> Function() reload;
  final Future<String> Function([bool forceRefresh]) getIdToken;
  final bool isLoggedIn;

  AuthUser(this.id,
      {required this.displayName,
      required this.email,
      required this.emailVerified,
      required this.sendVerificationEmail,
      required this.reload,
      required this.getIdToken,
      this.isLoggedIn = false});

  AuthUser.notLoggedIn()
      : this("",
            displayName: "",
            email: "",
            emailVerified: false,
            sendVerificationEmail: () => throw Exception(
                "User is not logged in. Cannot send verification email"),
            reload: () =>
                throw Exception("User is not logged in. Cannot reload"),
            getIdToken: ([bool? forceRefresh]) =>
                throw Exception("User is not logged in. Cannot get id token"),
            isLoggedIn: false);

  @override
  String toString() {
    return 'AuthUser{id: $id, displayName: $displayName, email: $email, emailVerified: $emailVerified, isLoggedIn: $isLoggedIn}';
  }
}
