import 'package:firebase_auth_helper/firebase_auth_helper.dart';
import 'package:flutter/cupertino.dart';

class AuthStateWrapper extends StatelessWidget {
  final AuthProvider authProvider;
  final WidgetBuilder signedIn; // home page
  final WidgetBuilder notSignedIn; // a login page
  final WidgetBuilder loading; // loading indicator
  final Widget Function(BuildContext context, Object? error)
      error; // error view

  const AuthStateWrapper(
      {required this.authProvider,
      required this.signedIn,
      required this.notSignedIn,
      required this.loading,
      required this.error,
      Key? key})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return StreamBuilder<AuthUser>(
        stream: authProvider.authStateChanged,
        builder: (context, snapshot) {
          print("Auth state changed: $snapshot");
          if (snapshot.connectionState == ConnectionState.waiting) {
            return loading(context);
          } else if (snapshot.hasError) {
            return error(context, snapshot.error);
          } else if (snapshot.hasData) {
            if (snapshot.data!.isLoggedIn) {
              return signedIn(context);
            } else {
              return notSignedIn(context);
            }
          }
          return error(context,
              "AuthStateWrapper: No unhandled state of snapshot: $snapshot");
        });
  }
}
